from sql_helper import dbb
afk = dbb["I_AFK"]


async def go_fk(time, reason=""):
    midhun = await afk.find_one({"_id": "AFK"})
    if midhun:
        await afk.update_one({"_id": "AFK"}, {"$set": {"time": time, "reason": reason}})
    else:
        await afk.insert_one({"_id": "AFK", "time": time, "reason": reason})


async def no_fk():
    midhun = await afk.find_one({"_id": "AFK"})
    if midhun:
        await afk.delete_one({"_id": "AFK"})


async def check_fk():
    midhun = await afk.find_one({"_id": "AFK"})
    if midhun:
        return midhun
    else:
        return None



from sql_helper import dbb

autoposter = dbb["AutoPoster"]


async def add_new_autopost(to_channel, target_channel):
    await autoposter.insert_one(
        {"target_channel": int(target_channel), "to_channel": int(to_channel)}
    )


async def check_if_autopost_in_db(to_channel, target_channel):
    st = await autoposter.find_one(
        {"target_channel": int(target_channel), "to_channel": int(to_channel)}
    )
    if st:
        return True
    else:
        return False


async def del_autopost(to_channel, target_channel):
    await autoposter.delete_one(
        {"target_channel": int(target_channel), "to_channel": int(to_channel)}
    )


async def get_autopost(target_channel):
    sed = [s async for s in autoposter.find({"target_channel": int(target_channel)})]
    return sed



import sys
from os.path import dirname
from typing import List
import time

def __list_all_modules():
    from os.path import dirname, basename, isfile
    import glob
    # This generates a list of modules in this folder for the * in __main__ to work.
    mod_paths = glob.glob(dirname(__file__) + "/*.py")
    all_modules = [basename(f)[:-3] for f in mod_paths if isfile(f)
                   and f.endswith(".py")
                   and not f.endswith('__init__.py')]
    to_load = all_modules
    return to_load
    return all_modules
def get_all_plugins() -> List[str]:
    """ list all plugins """
    plugins = get_import_path(ROOT, "/" if len(sys.argv) == 2 and sys.argv[1] == 'dev' else "/**/")
    _LOG.debug("All Available Plugins: %s", plugins)
    return list(plugins)

__all__ = ['ROOT', 'get_all_plugins']
ALL_INB= sorted(__list_all_modules())
#log.info("Userbot module loaded: %s", str(ALL_OWN))
__all__ = ALL_INB + ["ALL_INB"]



import pytgcalls
import os
from datetime import datetime
from distutils.util import strtobool as sb
from logging import DEBUG, INFO, basicConfig, getLogger
from logging import warning as wr
from pyrogram import Client
from pyrogram.types import Message
from decouple import config
from sqlalchemy import create_engine, exc
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import sessionmaker, scoped_session
from redis import ConnectionError, ResponseError, StrictRedis
from uti.confi import Var
LOGS = getLogger(__name__)

starttimer=datetime.now()
if not Var.API_ID or not Var.API_HASH:
    wr("No API_ID or API_HASH found.    Quiting...")
    exit(1)

Adminsettings= [Var.OWNER_ID]
# Adminsettings= Adminsettings.append(Var.OWNER_ID)


START_TIME = datetime.now()


try:
    redis_info = Var.REDIS_URI.split(":")
    vr = StrictRedis(
        host=redis_info[0],
        port=redis_info[1],
        password=Var.REDIS_PASSWORD,
        charset="utf-8",
        decode_responses=True,
    )
except ConnectionError as ce:
    wr(f"ERROR - {ce}")
    exit(1)
except ResponseError as res:
    wr(f"ERROR - {res}")
    exit(1)

try:
    if vr.get("HNDLR"):
        HNDLR = vr.get("HNDLR")
    else:
        vr.set("HNDLR", ".")
        HNDLR = vr.get("HNDLR")
except BaseException:
    pass

if vr.get("SUDOS") is None:
    vr.set("SUDOS", "1")
if vr.get("VC_SESSION"):
    vc_session=vr.get("VC_SESSION")
    vc_api_id= vr.get("VC_API_ID")
    vc_api_hash=vr.get("VC_API_HASH")
    vcbot = Client(vc_session, api_id=vc_api_id, api_hash=vc_api_hash)
else:
    vcbot = None


# Postgresqlw5mj by
#def mulaisql() -> scoped_session:


async def get_bot_inline(bot):
    global BOTINLINE_AVAIABLE
    if setbot:
        try:
            await naruto.get_inline_bot_results("@{}".format(bot.username), "test")
            BOTINLINE_AVAIABLE = True
        except errors.exceptions.bad_request_400.BotInlineDisabled:
            BOTINLINE_AVAIABLE = False


async def get_self():
    global Owner, OwnerName, OwnerUsername
    getself = await kingbot.get_me()
#     Adminsettings={}
    Owner = getself.id
    vr.set("SUDOS" , Owner)
    if getself.last_name:
        OwnerName = getself.first_name + " " + getself.last_name
    else:
        OwnerName = getself.first_name
    OwnerUsername = getself.username
    
       

async def get_bot():
    global BotID, BotName, BotUsername
    getbot = await setbot.get_me()
    BotID = getbot.id
    BotName = getbot.first_name
    BotUsername = getbot.username


BASE = declarative_base()
setbot = Client(":memory:",api_id=Var.API_ID, api_hash=Var.API_HASH, bot_token=Var.BOT_TOKEN )
kingbot = Client(Var.SESSION, api_id=Var.API_ID, api_hash=Var.API_HASH)
async def edrep(msg: Message, **kwargs):
    func = msg.edit_text if msg.from_user.is_self else msg.reply
    spec = getfullargspec(func.__wrapped__).args
    await func(**{k: v for k, v in kwargs.items() if k in spec})



from pyrogram.types import InlineKeyboardButton


class EqInlineKeyboardButton(InlineKeyboardButton):
    def __eq__(self, other):
        return self.text == other.text

    def __lt__(self, other):
        return self.text < other.text

    def __gt__(self, other):
        return self.text > other.text


def paginate_modules(_page_n, module_dict, prefix, chat=None):
    modules = sorted(
        [EqInlineKeyboardButton(x,
                                callback_data="{}_module({})".format(prefix, x.lower())) for x
         in module_dict.keys()])
   
    pairs = [
    modules[i * 3:(i + 1) * 3] for i in range((len(modules) + 3 - 1) // 3)
    ]
    round_num = len(modules) / 3
    calc = len(modules) - round(round_num)
    if calc == 1:
        pairs.append((modules[-1], ))
    elif calc == 2:
        pairs.append((modules[-1],))

    return pairs




import asyncio
import importlib
import sys
import time
import traceback
from pyrogram import idle
from pyrogram.types import InlineKeyboardMarkup, InlineKeyboardButton , InlineQuery ,Message, CallbackQuery, InlineQueryResultPhoto
from pyrogram import filters 
# import kingbot
from kingbot import kingbot ,setbot , get_bot , get_self, vr ,Adminsettings, vcbot
from assistant import ALL_AST
from adminss import ALL_ADMINN
from utilss import ALL_UTILS
from ownerr import ALL_OWN
from kingbot.plugins import ALL_INB
from uti.serra import ser
from uti.confi import Var
loop = asyncio.get_event_loop()
HNDLR="."
BOT_RUNTIME = 0
HELP_COMMANDU = {}
HELP_COMMANDA = {}
HELP_COMMANDO = {}
HELP_COMMANDAST = {}
HELP_COMMANDS = {}
async def get_runtime():
    return BOT_RUNTIME

async def reload_userbot():
    await kingbot.start()
    for modul in ALL_MODULES:
        imported_module = importlib.import_module("utilss." + modul)
        imported_module = importlib.import_module("ownerr." + modul)
        imported_module = importlib.import_module("adminss." + modul)
        importlib.reload(imported_module)


async def reinitial_restart():
    await get_bot()
    await get_self()


async def reboot():
    importlib.reload(importlib.import_module("adminss"))
    importlib.reload(importlib.import_module("ownerr"))
    importlib.reload(importlib.import_module("utilss"))
    importlib.reload(importlib.import_module("assistant"))
    # await setbot.send_message(Owner, "Bot is restarting...")
    await setbot.restart()
    await kingbot.restart()
    await reinitial_restart()
    # Reset global var
    BOT_RUNTIME = 0
    HELP_COMMANDU = {}
    HELP_COMMANDA = {}
    HELP_COMMANDO = {}
    HELP_COMMANDAST = {}
    # Assistant bot
    
    for modul in ALL_UTILS:
        imported_module = importlib.import_module("utilss." + modul)
        if hasattr(imported_module, "__MODULE__") and imported_module.__MODULE__:
            imported_module.__MODULE__ = imported_module.__MODULE__
        if hasattr(imported_module, "__MODULE__") and imported_module.__MODULE__:
            if not imported_module.__MODULE__.lower() in HELP_COMMANDU:
                HELP_COMMANDU[imported_module.__MODULE__.lower()] = imported_module
            else:
                raise Exception("Can't have two modules with the same name! Please change one")
        if hasattr(imported_module, "__HELP__") and imported_module.__HELP__:
            HELP_COMMANDU[imported_module.__MODULE__.lower()] = imported_module
        importlib.reload(imported_module)
    for modula in ALL_ADMINN:
        imported_module = importlib.import_module("adminss." + modula)
        if hasattr(imported_module, "__MODULE__") and imported_module.__MODULE__:
            imported_module.__MODULE__ = imported_module.__MODULE__
        if hasattr(imported_module, "__MODULE__") and imported_module.__MODULE__:
            if not imported_module.__MODULE__.lower() in HELP_COMMANDA:
                HELP_COMMANDA[imported_module.__MODULE__.lower()] = imported_module
            else:
                raise Exception("Can't have two modules with the same name! Please change one")
        if hasattr(imported_module, "__HELP__") and imported_module.__HELP__:
            HELP_COMMANDA[imported_module.__MODULE__.lower()] = imported_module
        importlib.reload(imported_module)
    for modulst in ALL_OWN:
        imported_module = importlib.import_module("ownerr." + modulst)
        if hasattr(imported_module, "__MODULE__") and imported_module.__MODULE__:
            imported_module.__MODULE__ = imported_module.__MODULE__
        if hasattr(imported_module, "__MODULE__") and imported_module.__MODULE__:
            if not imported_module.__MODULE__.lower() in HELP_COMMANDO:
                HELP_COMMANDO[imported_module.__MODULE__.lower()] = imported_module
            else:
                raise Exception("Can't have two modules with the same name! Please change one")
        if hasattr(imported_module, "__HELP__") and imported_module.__HELP__:
            HELP_COMMANDO[imported_module.__MODULE__.lower()] = imported_module
        importlib.reload(imported_module)
    for modula in ALL_AST:
            imported_module = importlib.import_module("assistant." + modul)
            if hasattr(imported_module, "__MODULE__") and imported_module.__MODULE__:
                imported_module.__MODULE__ = imported_module.__MODULE__
            if hasattr(imported_module, "__MODULE__") and imported_module.__MODULE__:
                if not imported_module.__MODULE__.lower() in HELP_COMMANDAST:
                    HELP_COMMANDAST[imported_module.__MODULE__.lower()] = imported_module
                else:
                    raise Exception("Can't have two modules with the same name! Please change one")
            if hasattr(imported_module, "__HELP__") and imported_module.__HELP__:
                HELP_COMMANDAST[imported_module.__MODULE__.lower()] = imported_module
            importlib.reload(imported_module)
    HELP_COMMANDS = {**HELP_COMMANDA,**HELP_COMMANDU,**HELP_COMMANDO, **HELP_COMMANDAST}
# await setbot.send_message(Owner, "Restart successfully!")

async def restart_all():
    # Restarting and load all plugins
    asyncio.get_event_loop().create_task(reboot())


RANDOM_STICKERS = ["CAADAgAD6EoAAuCjggf4LTFlHEcvNAI", "CAADAgADf1AAAuCjggfqE-GQnopqyAI",
                   "CAADAgADaV0AAuCjggfi51NV8GUiRwI"]


async def except_hook(errtype, value, tback):
    sys.__excepthook__(errtype, value, tback)
    errors = traceback.format_exception(etype=errtype, value=value, tb=tback)
    button = InlineKeyboardMarkup([[InlineKeyboardButton("🐞 Report bugs", callback_data="report_errors")]])
    text = "An error has accured!\n\n```{}```\n".format("".join(errors))
    if errtype == ModuleNotFoundError:
        text += "\nHint: Try this in your terminal `pip install -r requirements.txt`"
    await setbot.send_message(Owner, text, reply_markup=button)


async def reinitial():
    await kingbot.start()
    await setbot.start()
    await get_self()
    await get_bot()
    await kingbot.stop()
    await setbot.stop()


async def start_bot():
    global BOT_RUNTIME, HELP_COMMANDS, HELP_COMMANDU, HELP_COMMANDA, HELP_COMMANDO, HELP_COMMANDAST
    # sys.excepthook = except_hook
    vr.set("Owne", Var.OWNER_ID)
    print("----- Checking user and bot... -----")
    await reinitial()
    print("----------- Check done! ------------")
    # Assistant bot
    if vcbot is not None:
         await vcbot.start()
    await setbot.start()
    await kingbot.start()
    HELP_COMMANDU = {}
    HELP_COMMANDA = {}
    HELP_COMMANDO = {}
    HELP_COMMANDAST = {}
    for modul in ALL_UTILS:
        imported_module = importlib.import_module("utilss." + modul)
        if hasattr(imported_module, "__MODULE__") and imported_module.__MODULE__:
            imported_module.__MODULE__ = imported_module.__MODULE__
        if hasattr(imported_module, "__MODULE__") and imported_module.__MODULE__:
            if not imported_module.__MODULE__.lower() in HELP_COMMANDU:
                HELP_COMMANDU[imported_module.__MODULE__.lower()] = imported_module.__HELP__
            else:
                raise Exception("Can't have two modules with the same name! Please change one")
        if hasattr(imported_module, "__HELP__") and imported_module.__HELP__:
            HELP_COMMANDU[imported_module.__MODULE__.lower()] = imported_module.__HELP__
    for modula in ALL_ADMINN:
        imported_module = importlib.import_module("adminss." + modula)
        if hasattr(imported_module, "__MODULE__") and imported_module.__MODULE__:
            imported_module.__MODULE__ = imported_module.__MODULE__
        if hasattr(imported_module, "__MODULE__") and imported_module.__MODULE__:
            if not imported_module.__MODULE__.lower() in HELP_COMMANDA:
                HELP_COMMANDA[imported_module.__MODULE__.lower()] = imported_module
            else:
                raise Exception("Can't have two modules with the same name! Please change one")
        if hasattr(imported_module, "__HELP__") and imported_module.__HELP__:
            HELP_COMMANDA[imported_module.__MODULE__.lower()] = imported_module.__HELP__
    for modulst in ALL_OWN:
        imported_module = importlib.import_module("ownerr." + modulst)
        if hasattr(imported_module, "__MODULE__") and imported_module.__MODULE__:
            imported_module.__MODULE__ = imported_module.__MODULE__
        if hasattr(imported_module, "__MODULE__") and imported_module.__MODULE__:
            if not imported_module.__MODULE__.lower() in HELP_COMMANDO:
                HELP_COMMANDO[imported_module.__MODULE__.lower()] = imported_module
            else:
                raise Exception("Can't have two modules with the same name! Please change one")
        if hasattr(imported_module, "__HELP__") and imported_module.__HELP__:
            HELP_COMMANDO[imported_module.__MODULE__.lower()] = imported_module.__HELP__
    for moduli in ALL_AST:
            imported_module = importlib.import_module("assistant." + moduli)
            if hasattr(imported_module, "__MODULE__") and imported_module.__MODULE__:
                imported_module.__MODULE__ = imported_module.__MODULE__
            if hasattr(imported_module, "__MODULE__") and imported_module.__MODULE__:
                if not imported_module.__MODULE__.lower() in HELP_COMMANDAST:
                    HELP_COMMANDAST[imported_module.__MODULE__.lower()] = imported_module
                else:
                    raise Exception("Can't have two modules with the same name! Please change one")
            if hasattr(imported_module, "__HELP__") and imported_module.__HELP__:
                HELP_COMMANDAST[imported_module.__MODULE__.lower()] = imported_module.__HELP__
    for moduloo in ALL_INB:
        imported_module = importlib.import_module("kingbot.plugins." + moduloo)
        if hasattr(imported_module, "__MODULE__") and imported_module.__MODULE__:
            imported_module.__MODULE__ = imported_module.__MODULE__
        if hasattr(imported_module, "__MODULE__") and imported_module.__MODULE__:
            if not imported_module.__MODULE__.lower() in HELP_COMMANDO:
                HELP_COMMANDO[imported_module.__MODULE__.lower()] = imported_module
            else:
                raise Exception("Can't have two modules with the same name! Please change one")
        if hasattr(imported_module, "__HELP__") and imported_module.__HELP__:
            HELP_COMMANDO[imported_module.__MODULE__.lower()] = imported_module.__HELP__
    ser.HU=HELP_COMMANDU
    ser.HA=HELP_COMMANDA
    ser.HO=HELP_COMMANDO
    ser.HAT=HELP_COMMANDAST
    HELP_COMMANDS = {**HELP_COMMANDA,**HELP_COMMANDU,**HELP_COMMANDO, **HELP_COMMANDAST}
    ser.HC=HELP_COMMANDS
    await idle()
if __name__ == '__main__':
    BOT_RUNTIME = int(time.time())
    loop.run_until_complete(start_bot())




from sql_helper import dbb

gmuteh = dbb["GMUTE"]


async def is_gmuted(sender_id):
    kk = await gmuteh.find_one({"sender_id": sender_id})
    if not kk:
        return False
    else:
        return True


async def gmute(sender_id, reason="#GMuted"):
    await gmuteh.insert_one({"sender_id": sender_id, "reason": reason})


async def ungmute(sender_id):
    await gmuteh.delete_one({"sender_id": sender_id})



import os
import heroku3
from decouple import config
from dotenv import find_dotenv, load_dotenv

load_dotenv(find_dotenv())

def fetch_heroku_git_url(api_key, app_name):
    heroku = heroku3.from_key(api_key)
    try:
        heroku_applications = heroku.apps()
    except:
        return None
    heroku_app = None
    for app in heroku_applications:
        if app.name == app_name:
            heroku_app = app
            break
    if not heroku_app:
        return None
    return heroku_app.git_url.replace("https://", "https://api:" + api_key + "@")

class Var(object):
    # Mandatory
    API_ID = config("API_ID", default=None, cast=int)
    API_HASH = config("API_HASH", default=None)
    BOT_TOKEN = config("BOT_TOKEN", default=None)
    BOT_USERNAME = config("BOT_USERNAME", default=None)
    SESSION = config("SESSION", default=None)
    DB_URL = config("DATABASE_URL", default=None)
    LOG_CHANNEL = config("LOG_CHANNEL", default=None, cast=int)
    BLACKLIST_CHAT = set(int(x) for x in config("BLACKLIST_CHAT", "").split())
    OWNER_ID = config("OWNER_ID", default=None, cast=int)
    MONGO_DB = config("MONGO_DATABASE", default=None)
    try:
        HEROKU_APP_NAME = config("HEROKU_APP_NAME", default=None)
        HEROKU_API = config("HEROKU_API", default=None)
    except BaseException:
        HEROKU_APP_NAME = None
        HEROKU_API = None
    REDIS_URI = config("REDIS_URI", default=None)
    REDIS_PASSWORD = config("REDIS_PASSWORD", default=None)
    UPSTREAM_REPO = os.environ.get(
        "UPSTREAM_REPO", "https://github.com/ToxicCybers/kinguserbot"
    )
    U_BRANCH = "ToxicCyber"
    if HEROKU_API and HEROKU_APP_NAME:
        HEROKU_URL = fetch_heroku_git_url(HEROKU_API, HEROKU_APP_NAME)
    else:
        HEROKU_URL  =None



try:
    from sql_helper import BASE, SESSION
except ImportError:
    raise AttributeError
from sqlalchemy import Column, String, UnicodeText
from sqlalchemy.sql.expression import false
from sqlalchemy.sql.functions import user
from sqlalchemy.sql.sqltypes import Integer

warns=3 #max number of warning for a user

class User(BASE):
    __tablename__ = "permitted"
    user_id = Column(Integer, primary_key=True, nullable=False)
    warning = Column(Integer, primary_key=True, default=0)

    def __init__(self, variable):
        self.user_id = variable

    def __init__(self , userid , warning):
        self.user_id=userid
        self.warning=warning

User.__table__.create(checkfirst=True)

def givepermit(userid): # to give a permit to the user just pass the user id (can be a new user or old user with already warns), it would be updated in the db connected and warning would go to -1 i.e it is permitted
    if SESSION.query(User).filter(User.user_id == userid).one_or_none():
        SESSION.query(User).filter(User.user_id == userid).update({
            User.warning: -1
        })
    else:
        adduser=User(userid,-1)
        SESSION.add(adduser)
        SESSION.commit()

def checkpermit(userid): # if warning is -1(permitted) then returns true , if warning is warns(blocked) then returns false
    if SESSION.query(User).filter(User.user_id == userid).one_or_none():
        return SESSION.query(User).filter(User.user_id == userid).one_or_none().warning == -1
    else:
        if SESSION.query(User).filter(User.user_id == userid).one_or_none():
            return not (SESSION.query(User).filter(User.user_id == userid).one_or_none().warning == warns)

def blockuser(userid): # blocks a user by changing it's warning to warns(max warns)
    if SESSION.query(User).filter(User.user_id == userid).one_or_none():
        SESSION.query(User).filter(User.user_id == userid).update({
            User.warning: warns
        })
    else:
        adduser=User(userid,warns)
        SESSION.add(adduser)
        SESSION.commit()

def getwarns(userid): # to get warns of a specific user if it exists in db
    if SESSION.query(User).filter(User.user_id == userid).one_or_none():
        return SESSION.query(User).filter(User.user_id == userid).one_or_none().warning
    else:
        return "USER DON'T EXISTS"

def addwarns(userid): # updates the warning by 1 each time it is called , or gives a warn to the user if already not present
    if SESSION.query(User).filter(User.user_id == userid).one_or_none():
        SESSION.query(User).filter(User.user_id == userid).update({
            User.warning: User.warning+1
        })
    else:
        adduser=User(userid,1)
        SESSION.add(adduser)
        SESSION.commit()    


def allallowed():
    query = SESSION.query(User).filter(User.warning == -1)
    alloweduser=[]
    for row in query:
        alloweduser.append(row.user_id)
    return alloweduser

def allblocked():
    query = SESSION.query(User).filter(User.warning == warns)
    blockeduser=[]
    for row in query:
        blockeduser.append(row.user_id)
    return blockeduser

def inwarns():
    query = SESSION.query(User).filter(User.warning > -1 and User.warning<3)
    inwarns=[]
    for row in query:
        inwarns.append(row.user_id)
    return inwarns



import os
from sqlalchemy import create_engine
from sqlalchemy.ext.declarative import declarative_base
from sqlalchemy.orm import scoped_session, sessionmaker
from uti.confi import Var
import motor.motor_asyncio
mongo_dbb = motor.motor_asyncio.AsyncIOMotorClient(Var.MONGO_DB)
dbb = mongo_dbb["KING"]
def start() -> scoped_session:
    engine = create_engine(Var.DB_URL)
    BASE.metadata.bind = engine
    BASE.metadata.create_all(engine)
    return scoped_session(sessionmaker(bind=engine, autoflush=False))

def start() -> scoped_session:
    dbi_url=Var.DB_URL
    engine = create_engine(dbi_url)
    BASE.metadata.bind = engine
    BASE.metadata.create_all(engine)
    return scoped_session(sessionmaker(bind=engine, autoflush=False))

try:
    BASE = declarative_base()
    SESSION = start()
except AttributeError as e:
    print(
        "DB_URI is not configured. Features depending on the database might have issues."
    )
    print(str(e))



from uti.misc import paginate_modules
from pyrogram import idle
from pyrogram.types import InlineKeyboardMarkup, InlineKeyboardButton , InlineQuery ,Message, CallbackQuery, InputTextMessageContent, InlineQueryResultArticle
from pyrogram import filters 
from kingbot import kingbot ,setbot , vr,Adminsettings
from uti.serra import ser
import re
Admins= Adminsettings
Msge={}
@kingbot.on_message(filters.command("help",".") & filters.user(Adminsettings))
async def h_lp(_ , message):
  booet= await setbot.get_me()
  res=await kingbot.get_inline_bot_results(booet.username, "hlpin")
  mg= await kingbot.send_inline_bot_result(message.chat.id, res.query_id, res.results[0].id)
@setbot.on_inline_query(filters.regex("hlpin") & filters.user(Adminsettings))
async def in_h_lp(_ , inline_query):
    hno = ser.HC
    lengt = len(hno)
    stosen = InputTextMessageContent(
        message_text=f"You are accessing help for **King Userbot** \n __Everyone is a king. Until the real king arrives.__ \n\n ♕𝚃𝚘𝚝𝚊𝚕 𝙲𝚘𝚖𝚖𝚊𝚗𝚍𝚜♛= {𝚕𝚎𝚗𝚐𝚝}")
    keboard = InlineKeyboardMarkup(
        [[
            InlineKeyboardButton(
                "👨‍✈️ admin",
                callback_data="_admin_h"
            ),
            InlineKeyboardButton(
                "🧰 tools",
                callback_data="_util_h"
            )
        ],
            [
                InlineKeyboardButton(
                    "⚙️ Assistant",
                    callback_data="_ast_h"
                ),
                InlineKeyboardButton(
                    "🤹 Owner",
                    callback_data="_own_h"
                )
            ],
            [
                InlineKeyboardButton(
                    "Close❌",
                    callback_data="kloz"
                )], [
            InlineKeyboardButton(
                "Support",
                url="https://t.me/Tc_Bots"
            )]])
    await inline_query.answer(
        results=[
            InlineQueryResultArticle(
                title="Help",
                input_message_content=stosen,
                reply_markup=keboard,
            ),
        ]
    )
def cowner(func):
        async def wrapper(_, cbq: CallbackQuery):
            if cbq.from_user.id in AdminSettings:
                pass
            else:
                userr = await setbot.get_user(Owner)
                await cbq.answer(
                    f"Only {userr.first_name} Can Access this...! Get yourself a Userbot🤘",
                    show_alert=True)
        return wrapper

@setbot.on_callback_query(filters.user(Adminsettings))
async def cbire(_ , cbq: CallbackQuery):
   HELP_COMMANDU = ser.HU
   HELP_COMMANDA = ser.HA
   HELP_COMMANDO = ser.HO
   HELP_COMMANDAST = ser.HAT
   HELP_COMMANDS = ser.HC
   print(cbq) 
   cid=cbq.id
   cdt=cbq.data
   if cdt == "_admin_h":
      keyboard = paginate_modules(0, HELP_COMMANDA, "help")
      keyboard.append([InlineKeyboardButton(
                            "Back ◀️",
                            callback_data= "b_k"
             )])
      keyboard.append([InlineKeyboardButton(
                            "Close ❌",
                            callback_data= "kloz"
             )])
      await cbq.edit_message_caption(
                            caption=f"This is the help for admin commmands to manage your group efficiently",
                            )
      await cbq.edit_message_reply_markup(reply_markup=InlineKeyboardMarkup(keyboard))
      return
   if cdt == "_util_h":
      keyboard = paginate_modules(0, HELP_COMMANDU, "help")
      keyboard.append([InlineKeyboardButton(
                            "Back ◀️",
                            callback_data= "b_k"
             )])
      keyboard.append([InlineKeyboardButton(
                            "Close ❌",
                            callback_data= "kloz"
             )])
      await cbq.edit_message_caption(
                            caption="This is the help for util commmands to make your life easy peasy",
                            )
      await cbq.edit_message_reply_markup(reply_markup=InlineKeyboardMarkup(keyboard))
      return
   if cdt == "_ast_h":
      keyboard = paginate_modules(0, HELP_COMMANDAST, "help")
      keyboard.append([InlineKeyboardButton(
                            "Back ◀️",
                            callback_data= "b_k"
             )])
      keyboard.append([InlineKeyboardButton(
                            "Close ❌",
                            callback_data= "kloz"
             )])
      await cbq.edit_message_caption(
                            caption="This is the help for assistant commmands to manage your userbot",
                            )
      await cbq.edit_message_reply_markup(reply_markup=InlineKeyboardMarkup(keyboard))
      return
   if cdt == "_own_h":
      keyboard =   paginate_modules(0, HELP_COMMANDO, "help")
      keyboard.append([InlineKeyboardButton(
                            "Back ◀️",
                            callback_data= "b_k"
             )])
      keyboard.append([InlineKeyboardButton(
                            "Close ❌",
                            callback_data= "kloz"
             )])
      await cbq.edit_message_caption(
                            caption="This is the help for owner commmands ",
                            )
      await cbq.edit_message_reply_markup(reply_markup=InlineKeyboardMarkup(keyboard))
      return
   if cdt == "b_k":
        keyboard=[[
            InlineKeyboardButton(
                "👨‍✈️ admin",
                callback_data="_admin_h"
            ),
            InlineKeyboardButton(
                "🧰 tools",
                callback_data="_util_h"
            )
        ],
            [
                InlineKeyboardButton(
                    "⚙️ Assistant",
                    callback_data="_ast_h"
                ),
                InlineKeyboardButton(
                    "🤹 Owner",
                    callback_data="_own_h"
                )
            ],
            [
                InlineKeyboardButton(
                    "Close❌",
                    callback_data="kloz"
                )], [
            InlineKeyboardButton(
                "Support",
                url="https://t.me/Tc_Bots"
            )]]
        await cbq.edit_message_caption(
                            caption=f"You are accessing help for **King Userbot** \n __Everyone is a king. Until the real king arrives.__",
                            )
        await cbq.edit_message_reply_markup(reply_markup=InlineKeyboardMarkup(keyboard))
        return
   if cdt == "kloz":
       await cbq.edit_message_caption(
           caption=f"THE MENU HAS BEEN CLOSED",
       )
       keyboard = [[InlineKeyboardButton(
           "OPEN THE MENU AGAIN",
           callback_data="b_k"
       )]]
       await cbq.edit_message_reply_markup(reply_markup=InlineKeyboardMarkup(keyboard))
       return
   HELP_COMMANDS = ser.HC 
   mod_match = re.match(r"help_module\((.+?)\)", cbq.data)
   data=cbq.data
   module=data[data.index("(")+1:len(data)-1]
   back_match = re.match(r"b_k", cbq.data)
   if mod_match:
        if module in HELP_COMMANDS:
           modulee= module
        else:
           return
        text = (
            "This is help for the plugins **{}**:\n".format(
                modulee
            )
            + HELP_COMMANDS[modulee]
        )

        await cbq.edit_message_caption(caption=text)
        await cbq.edit_message_reply_markup(
            reply_markup=InlineKeyboardMarkup(
                [
                    [
                        InlineKeyboardButton(
                            text="Back ◀️",    
                            callback_data="b_k"
                        )
                    ]
                ]
            )
        )
                  

   elif back_match:
        keyboard=[[
            InlineKeyboardButton(
                "👨‍✈️ admin",
                callback_data="_admin_h"
            ),
            InlineKeyboardButton(
                "🧰 tools",
                callback_data="_util_h"
            )
        ],
            [
                InlineKeyboardButton(
                    "⚙️ Assistant",
                    callback_data="_ast_h"
                ),
                InlineKeyboardButton(
                    "🤹 Owner",
                    callback_data="_own_h"
                )
            ],
            [
                InlineKeyboardButton(
                    "Close❌",
                    callback_data="kloz"
                )], [
            InlineKeyboardButton(
                "Support",
                url="https://t.me/Tc_Bots"
            )]]
        await cbq.edit_message_caption(
                            caption=f"You are accessing help for **King Userbot** \n __Everyone is a king. Until the real king arrives.__",
                            )
        await cbq.edit_message_reply_markup(reply_markup=InlineKeyboardMarkup(keyboard))
   await cbq.answer()
# async def help_button_callback(_, __, query):
#     if re.match(r"help_", query.data):
#         return True


# help_button_create = filters.create(help_button_callback)
#@setbot.on_callback_query(filters.user(1359459092))
#async def help_button(_, query):  





from sql_helper import dbb

gbun = dbb["GBAN"]


async def gban_user(user, reason="#GBanned"):
    await gbun.insert_one({"user": user, "reason": reason})


async def ungban_user(user):
    await gbun.delete_one({"user": user})


async def gban_list():
    return [lo async for lo in gbun.find({})]


async def gban_info(user):
    kk = await gbun.find_one({"user": user})
    if not kk:
        return False
    else:
        return kk["reason"]
